@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 use parent 'Plack::Middleware';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require bytes;
 
@@ -13,7 +13,6 @@ use HTML::TreeBuilder::XPath;
 use Mojo::URL;
 use Plack::Util;
 use Plack::Util::Accessor qw( settings );
-use Try::Tiny;
 use URI::Escape;
 
 use Plack::Middleware::WOVN::Headers;
@@ -46,7 +45,7 @@ sub call {
     if ( $headers->path_lang eq $STORE->settings->{default_lang} ) {
         my $redirect_headers
             = $headers->redirect( $STORE->settings->{default_lang} );
-        return [ 307, [$redirect_headers], [''] ];
+        return [ 307, [%$redirect_headers], [''] ];
     }
     my $lang = $headers->lang_code;
 
